==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/gettext_po.md <==
## Gettext Source (.po)

### General Information

| Attribute       | Value                                                         |
| --------------- | ------------------------------------------------------------- |
| Name            | GettextPo                                                     |
| snake_case_name | gettext_po                                                    |
| Description     | Gettext Source (.po)                                          |
| Extensions      | `.po`                                                         |
| Read support    | Yes                                                           |
| Write support   | Yes                                                           |
| Single-file     | Yes                                                           |
| Kind            | 📝 text                                                        |
| Sort-on-write   | default_no                                                    |
| Sort key        | (`headword_lower`)                                            |
| Wiki            | [Gettext](https://en.wikipedia.org/wiki/Gettext)              |
| Website         | [gettext - GNU Project](https://www.gnu.org/software/gettext) |

### Write options

| Name      | Default | Type | Comment                       |
| --------- | ------- | ---- | ----------------------------- |
| resources | `True`  | bool | Enable resources / data files |

### Dependencies for reading and writing

PyPI Links: [polib](https://pypi.org/project/polib)

To install, run:

```sh
pip3 install polib
```

### Dictionary Applications/Tools

| Name & Website                                   | License         | Platforms           |
| ------------------------------------------------ | --------------- | ------------------- |
| [gettext](https://www.gnu.org/software/gettext/) | GPL             | Linux, Windows      |
| [poEdit](https://github.com/vslavik/poedit)      | MIT / Shareware | Linux, Windows, Mac |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/gettext_po.md <==
## Gettext Source (.po)

### General Information

| Attribute       | Value                                                         |
| --------------- | ------------------------------------------------------------- |
| Name            | GettextPo                                                     |
| snake_case_name | gettext_po                                                    |
| Description     | Gettext Source (.po)                                          |
| Extensions      | `.po`                                                         |
| Read support    | Yes                                                           |
| Write support   | Yes                                                           |
| Single-file     | Yes                                                           |
| Kind            | 📝 text                                                        |
| Sort-on-write   | No (by default)                                               |
| Sort key        | (`headword_lower`)                                            |
| Wiki            | [Gettext](https://en.wikipedia.org/wiki/Gettext)              |
| Website         | [gettext - GNU Project](https://www.gnu.org/software/gettext) |

### Write options

| Name      | Default | Type | Comment                       |
| --------- | ------- | ---- | ----------------------------- |
| resources | `True`  | bool | Enable resources / data files |

### Dependencies for reading and writing

PyPI Links: [polib](https://pypi.org/project/polib)

To install, run:

```sh
pip3 install polib
```

### Dictionary Applications/Tools

| Name & Website                                   | Source code | License         | Platforms           | Language |
| ------------------------------------------------ | ----------- | --------------- | ------------------- | -------- |
| [gettext](https://www.gnu.org/software/gettext/) | ―           | GPL             | Linux, Windows      |          |
| [poEdit](https://github.com/vslavik/poedit)      | ―           | MIT / Shareware | Linux, Windows, Mac |          |
